initializeTimeout property
How long FeatClient.initialize waits for the first evaluation before returning anyway (serving cached/empty values in the meantime).
Implementation
final Duration initializeTimeout;
How long FeatClient.initialize waits for the first evaluation before returning anyway (serving cached/empty values in the meantime).
final Duration initializeTimeout;